@@ -8,14 +8,15 @@ NAME = "bibtexautocomplete"
 SCRIPT_NAME = "btac"
 AUTHOR = "Dorian Lesbre"
 URL = "https://github.com/dlesbre/bibtex-autocomplete"
+ISSUES_URL = URL + "/issues"
 LICENSE = "MIT"
 DESCRIPTION = "Module to complete bibtex files by polling online databases"
 
 VERSION_MAJOR = 1
 VERSION_MINOR = 1
-VERSION_PATCH = 5
+VERSION_PATCH = 8
 
-VERSION_DATE = "2022-09-21"
+VERSION_DATE = "2023-02-27"
 
 VERSION = (VERSION_MAJOR, VERSION_MINOR, VERSION_PATCH)
 VERSION_STR = f"{VERSION_MAJOR}.{VERSION_MINOR}.{VERSION_PATCH}"
@@ -24,7 +25,7 @@ EMAIL = "dorian.lesbre" + chr(64) + "gmail.com"
 
 # Minimum delay between queries to same host, to avoid surcharging server
 MIN_QUERY_DELAY = 0.02  # s, so 50 per second
-CONNECTION_TIMEOUT = 10.0  # seconds
+CONNECTION_TIMEOUT = 20.0  # seconds
 
 USER_AGENT = f"{NAME}/{VERSION_STR} ({URL}; mailto:{EMAIL})"
 
@@ -39,7 +40,10 @@ BTAC_FILENAME = "{name}.btac{suffix}"
 
 # Most APIs allow to limit the number of results returned for a search query
 # This allows for smaller data transfers
-QUERY_MAX_RESULTS = 3
+QUERY_MAX_RESULTS = 10
 
 # Prefix added to fields with -p / --prefix option
 FIELD_PREFIX = "BTAC"
+
+# Bullet printed to the screen when printing a list
+BULLET = "{FgBlue}{StBold}*{Reset} "
